@@ -1,4 +1,5 @@
 import inspect
+import sys
 from typing import List, Callable
 
 import anytree
@@ -29,16 +30,13 @@ class ArgParserNode(anytree.NodeMixin):
         """Creating a subparser requires tracking a 'subparser action object' -- we refer to this
         as the 'subparser_factory.' This method creates and configures that 'subparser action object'.
         """
-        try:
+        if sys.version_info.minor >= 7:
             self._subparser_factory = self._parser.add_subparsers(
                 required=True, 
                 dest="subcommand", 
                 parser_class=configargparse.ArgParser
             )
-        except TypeError as e:  # Python 3.6 support: 'required=True' argument may cause TypeError
-            # Re-Raise if error is something other than '... unexpected argument 'required''.
-            if "got an unexpected keyword argument 'required'" not in str(e):
-                raise e
+        else:  # Python 3.6 support: 'required=True' argument may cause TypeError.
             self._subparser_factory = self._parser.add_subparsers(
                 dest="subcommand", 
                 parser_class=configargparse.ArgParser
